libjpeg: JPEG image support
===========================

Description
-----------

This dummy package represents the image library ``libjpeg``.

We do not have an SPKG for it. The purpose of this dummy package is to
associate system package lists with it.

If the system package is installed, the package ``pillow`` will include
support for JPEG images.
